pub struct SpatialScaler { /* private fields */ }Expand description
Re-exports the Metal framework surface for this item.
Apple’s id<MTLFXSpatialScaler> — MetalFX’s spatial upscaler.
Mirrors the Metal framework counterpart for this type.
Implementations
Sourceimpl SpatialScaler
impl SpatialScaler
Sourceimpl SpatialScaler
impl SpatialScaler
Sourcepub fn color_texture_usage(&self) -> usize
pub fn color_texture_usage(&self) -> usize
Required texture usage bits for the input color texture.
Sourcepub fn output_texture_usage(&self) -> usize
pub fn output_texture_usage(&self) -> usize
Required texture usage bits for the output texture.
Sourcepub fn configure(
&self,
input_content_width: usize,
input_content_height: usize,
color_texture: &MetalTexture,
output_texture: &MetalTexture,
fence: Option<&Fence>,
)
pub fn configure( &self, input_content_width: usize, input_content_height: usize, color_texture: &MetalTexture, output_texture: &MetalTexture, fence: Option<&Fence>, )
Configure the textures and content size for one upscaling pass.
Sourcepub fn encode_to_command_buffer(&self, command_buffer: &CommandBuffer)
pub fn encode_to_command_buffer(&self, command_buffer: &CommandBuffer)
Encode this scaler’s work into a command buffer.