pub struct TemporalScalerDescriptor {Show 15 fields
pub color_texture_format: usize,
pub depth_texture_format: usize,
pub motion_texture_format: usize,
pub output_texture_format: usize,
pub input_width: usize,
pub input_height: usize,
pub output_width: usize,
pub output_height: usize,
pub auto_exposure_enabled: bool,
pub requires_synchronous_initialization: bool,
pub input_content_properties_enabled: bool,
pub input_content_min_scale: f32,
pub input_content_max_scale: f32,
pub reactive_mask_texture_enabled: bool,
pub reactive_mask_texture_format: usize,
}Expand description
Re-exports the Metal framework surface for this item.
Safe Rust description of MTLFXTemporalScalerDescriptor.
Fields
color_texture_format: usizeMirrors the Metal framework property for color_texture_format.
depth_texture_format: usizeMirrors the Metal framework property for depth_texture_format.
motion_texture_format: usizeMirrors the Metal framework property for motion_texture_format.
output_texture_format: usizeMirrors the Metal framework property for output_texture_format.
input_width: usizeMirrors the Metal framework property for input_width.
input_height: usizeMirrors the Metal framework property for input_height.
output_width: usizeMirrors the Metal framework property for output_width.
output_height: usizeMirrors the Metal framework property for output_height.
auto_exposure_enabled: boolMirrors the Metal framework property for auto_exposure_enabled.
requires_synchronous_initialization: boolMirrors the Metal framework property for requires_synchronous_initialization.
input_content_properties_enabled: boolMirrors the Metal framework property for input_content_properties_enabled.
input_content_min_scale: f32Mirrors the Metal framework property for input_content_min_scale.
input_content_max_scale: f32Mirrors the Metal framework property for input_content_max_scale.
reactive_mask_texture_enabled: boolMirrors the Metal framework property for reactive_mask_texture_enabled.
reactive_mask_texture_format: usizeMirrors the Metal framework property for reactive_mask_texture_format.
Implementations
Sourceimpl TemporalScalerDescriptor
impl TemporalScalerDescriptor
Sourcepub const fn new(
color_texture_format: usize,
depth_texture_format: usize,
motion_texture_format: usize,
output_texture_format: usize,
input_size: (usize, usize),
output_size: (usize, usize),
) -> Self
pub const fn new( color_texture_format: usize, depth_texture_format: usize, motion_texture_format: usize, output_texture_format: usize, input_size: (usize, usize), output_size: (usize, usize), ) -> Self
Create a MetalFX temporal-scaler descriptor.
Sourcepub fn supports_device(device: &MetalDevice) -> bool
pub fn supports_device(device: &MetalDevice) -> bool
Query whether the given device supports MetalFX temporal scaling.
Sourcepub fn supported_input_content_min_scale(device: &MetalDevice) -> f32
pub fn supported_input_content_min_scale(device: &MetalDevice) -> f32
Query the smallest supported temporal scale factor for a device.
Sourcepub fn supported_input_content_max_scale(device: &MetalDevice) -> f32
pub fn supported_input_content_max_scale(device: &MetalDevice) -> f32
Query the largest supported temporal scale factor for a device.