pub enum IOSurfaceMetalError {
InvalidPlane {
plane_index: usize,
plane_count: usize,
},
UnsupportedPixelFormat {
fourcc: u32,
plane_index: usize,
},
EmptyPlane {
plane_index: usize,
width: usize,
height: usize,
bytes_per_row: usize,
},
IncompatiblePlaneLayout {
plane_index: usize,
bytes_per_row: usize,
minimum_bytes_per_row: usize,
},
IntegerOutOfRange {
field: &'static str,
value: usize,
},
NativeCreationFailed,
}Available on crate feature
iosurface only.Expand description
Re-exports the Metal framework surface for this item.
Errors returned while creating an IOSurface-backed texture.
Variants
InvalidPlane
The requested plane does not exist for this surface.
UnsupportedPixelFormat
The surface format and plane do not map to a supported Metal format.
EmptyPlane
The selected plane has zero dimensions or row stride.
IncompatiblePlaneLayout
The plane row stride cannot contain its selected Metal format.
IntegerOutOfRange
Plane metadata cannot be represented by the native bridge.
NativeCreationFailed
Metal rejected the validated IOSurface texture descriptor.